/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: DelegatorOutputStream.java 4483 2009-01-26 08:47:13Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.stream.impl.delegator;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;

/**
 * @author Gael Lalire
 */
public class DelegatorOutputStream extends FileOutputStream {

    /**
     * Keep delegatorFileAccessor to avoid deletion of tmp file.
     */
    private DelegatorStreamAccessor delegatorFileAccessor;

    private File temporaryFile;

    public DelegatorOutputStream(final DelegatorStreamAccessor delegatorFileAccessor, final File file, final boolean temporary)
            throws FileNotFoundException {
        super(file);
        if (temporary) {
            this.temporaryFile = file;
        }
    }

    @Override
    public void flush() throws IOException {
        super.flush();
        if (temporaryFile == null) {
            delegatorFileAccessor.doWrite();
        }
    }

    @Override
    public void close() throws IOException {
        super.flush();
        super.close();
        if (temporaryFile != null) {
            delegatorFileAccessor.doWrite(temporaryFile);
        } else {
            delegatorFileAccessor.doWrite();
        }
    }

    @Override
    protected void finalize() {
        if (temporaryFile != null) {
            temporaryFile.delete();
        }
    }

}
